@@ -19,8 +19,8 @@
 ;; Keywords: languages, debug
 ;; URL: https://github.com/emacs-lsp/dap-mode
 ;; Package-Requires: ((emacs "28.1") (dash "2.18.0") (lsp-mode "6.0") (bui "1.1.0") (f "0.20.0") (s "1.12.0") (lsp-treemacs "0.1") (posframe "0.7.0") (ht "2.3") (lsp-docker "1.0.0"))
-;; Package-Version: 20251004.452
-;; Package-Revision: 6c74027e39fc
+;; Package-Version: 20251105.2320
+;; Package-Revision: ab96fc8e8df4
 
 ;;; Commentary:
 ;; Debug Adapter Protocol client for Emacs.
@@ -785,7 +785,7 @@ will be reversed."
   (-when-let* ((source (gethash "source" stack-frame))
                (sourceReference (gethash "sourceReference" source))
                (sourceReferenceKey (format "%s-%s" name sourceReference)))
-    (select-window (get-mru-window (selected-frame) nil))
+    (select-window (get-mru-window (dap--selected-frame) nil))
     (if-let* ((existing-buffer (get-buffer sourceReferenceKey)))
         (switch-to-buffer existing-buffer)
       (dap--send-message
@@ -811,6 +811,15 @@ will be reversed."
                          path)))
       (--> debug-session (dap--debug-session-remote-to-local-path-fn it) (funcall it remote-path)))))
 
+(defun dap--selected-frame ()
+  "Select the `main' frame when we have a utility/subframe selected."
+  (cl-labels ((helper (f)
+                (let ((parent-frame (frame-parameter f 'parent-frame)))
+                  (if parent-frame
+                      (helper parent-frame)
+                    f))))
+    (helper (selected-frame))))
+
 (defun dap--go-to-stack-frame (debug-session stack-frame)
   "Make STACK-FRAME the active STACK-FRAME of DEBUG-SESSION."
   (when stack-frame
@@ -822,7 +831,7 @@ will be reversed."
       ;; stack trace.
       (if (and path (file-exists-p path))
           (progn
-            (select-window (get-mru-window (selected-frame) nil))
+            (select-window (get-mru-window (dap--selected-frame) nil))
             (find-file path)
             (goto-char (point-min))
             (forward-line (1- line))
